==> ipynta-0.0.37.tar.gz: ipynta-0.0.37/README.md <==
[![Unit Tests](https://github.com/allanchua101/ipynta/actions/workflows/run_unit_tests.yml/badge.svg)](https://github.com/allanchua101/ipynta/actions/workflows/run_unit_tests.yml)
[![PyPI version](https://badge.fury.io/py/ipynta.svg)](https://badge.fury.io/py/ipynta)
[![PyPI download month](https://img.shields.io/pypi/dm/ipynta.svg)](https://pypi.python.org/pypi/ipynta/)
[![Maintained](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://github.com/allanchua101/ipynta/graphs/commit-activity)

<p align="center">
    <img  src="https://i.imgur.com/W1lha0W.jpeg"> 
</p>

<p align="center">
  <strong>ipynta</strong> is a Python library designed for rapid development of image pre-processing pipelines.
</p>

#### Installation

```sh
pip install ipynta
```

#### High level overview

<p align="center">
  <img src="https://i.imgur.com/xAewjot.png" />
</p>

<p align="center">
  The diagram above describes the purpose of each iPynta class family and how can they be used collectively in an image pre-processing pipeline.
</p>

#### Class Families

- [Extractors](https://github.com/allanchua101/ipynta/blob/main/docs/extractors/Readme.md)
- [Sourcing](https://github.com/allanchua101/ipynta/blob/main/docs/sourcing/Readme.md)
- [Loaders](https://github.com/allanchua101/ipynta/blob/main/docs/loaders/Readme.md)
- [Predicates](https://github.com/allanchua101/ipynta/blob/main/docs/predicates/Readme.md)
- [Transformers](https://github.com/allanchua101/ipynta/blob/main/docs/transform/Readme.md)

#### Why was it named ipynta?

`I-pinta` means _"to paint"_ in tagalog! This library is proudly developed by a Singapore-based Filipino lad with nothing better to do during evenings.

==> ipynta-0.0.39.tar.gz: ipynta-0.0.39/README.md <==
[![Unit Tests](https://github.com/allanchua101/ipynta/actions/workflows/run_unit_tests.yml/badge.svg)](https://github.com/allanchua101/ipynta/actions/workflows/run_unit_tests.yml)
[![PyPI version](https://badge.fury.io/py/ipynta.svg)](https://badge.fury.io/py/ipynta)
[![PyPI download month](https://img.shields.io/pypi/dm/ipynta.svg)](https://pypi.python.org/pypi/ipynta/)
[![Maintained](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://github.com/allanchua101/ipynta/graphs/commit-activity)

<p align="center">
    <img  src="https://i.imgur.com/W1lha0W.jpeg"> 
</p>

<p align="center">
  <strong>ipynta</strong> is a Python library designed for rapid development of image pre-processing pipelines.
</p>

#### Installation

```sh
pip install ipynta
```

#### High level overview

<p align="center">
  <img src="https://i.imgur.com/xAewjot.png" />
</p>

<p align="center">
  The diagram above describes the purpose of each iPynta class family and how can they be used collectively in an image pre-processing pipeline.
</p>

#### Core Class Families

- [Sourcing](https://github.com/allanchua101/ipynta/blob/main/docs/sourcing/Readme.md)
- [Predicates](https://github.com/allanchua101/ipynta/blob/main/docs/predicates/Readme.md)
- [Transformers](https://github.com/allanchua101/ipynta/blob/main/docs/transform/Readme.md)

#### Utility Class Families

- [Loaders](https://github.com/allanchua101/ipynta/blob/main/docs/loaders/Readme.md)
- [Packaging](https://github.com/allanchua101/ipynta/blob/main/docs/packaging/Readme.md)

#### Why was it named ipynta?

`I-pinta` means _"to paint"_ in tagalog! This library is proudly developed by a Singapore-based Filipino lad with nothing better to do during evenings.
